import inspect
import typing
from .base_response import BaseResponse
from vkbottle_types.objects import AppWidgetsPhoto, AppWidgetsPhotos


class GetAppImageUploadServerResponse(BaseResponse):
    response: "GetAppImageUploadServerResponseModel" = None


class GetAppImagesResponse(BaseResponse):
    response: AppWidgetsPhotos = None


class GetGroupImageUploadServerResponse(BaseResponse):
    response: "GetGroupImageUploadServerResponseModel" = None


class GetGroupImagesResponse(BaseResponse):
    response: AppWidgetsPhotos = None


class GetImagesByIdResponse(BaseResponse):
    response: typing.List["AppWidgetsPhoto"] = None


class SaveAppImageResponse(BaseResponse):
    response: AppWidgetsPhoto = None


class SaveGroupImageResponse(BaseResponse):
    response: AppWidgetsPhoto = None


class GetAppImageUploadServerResponseModel(BaseResponse):
    upload_url: typing.Optional[str] = None


class GetGroupImageUploadServerResponseModel(BaseResponse):
    upload_url: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()



import inspect
import typing
from .base_response import BaseResponse
from vkbottle_types.objects import (
    BaseBoolInt,
    GroupsAddress,
    GroupsBannedItem,
    GroupsCallbackServer,
    GroupsCallbackSettings,
    GroupsGroup,
    GroupsGroupAccess,
    GroupsGroupAgeLimits,
    GroupsGroupAudio,
    GroupsGroupCategory,
    GroupsGroupCategoryFull,
    GroupsGroupDocs,
    GroupsGroupFull,
    GroupsGroupFullSection,
    GroupsGroupPhotos,
    GroupsGroupPublicCategoryList,
    GroupsGroupSuggestedPrivacy,
    GroupsGroupTag,
    GroupsGroupTopics,
    GroupsGroupVideo,
    GroupsGroupWall,
    GroupsGroupWiki,
    GroupsLinksItem,
    GroupsLongPollServer,
    GroupsLongPollSettings,
    GroupsMemberRole,
    GroupsMemberStatus,
    GroupsMemberStatusFull,
    GroupsSectionsListItem,
    GroupsSettingsTwitter,
    GroupsSubjectItem,
    GroupsTokenPermissionSetting,
    GroupsUserXtrRole,
    UsersUserFull,
    UsersUserMin
)


class AddAddressResponse(BaseResponse):
    response: GroupsAddress = None


class AddCallbackServerResponse(BaseResponse):
    response: "AddCallbackServerResponseModel" = None


class AddLinkResponse(BaseResponse):
    response: GroupsLinksItem = None


class CreateResponse(BaseResponse):
    response: GroupsGroup = None


class EditAddressResponse(BaseResponse):
    response: GroupsAddress = None


class GetAddressesResponse(BaseResponse):
    response: "GetAddressesResponseModel" = None


class GetBannedResponse(BaseResponse):
    response: "GetBannedResponseModel" = None


class GetByIdObjectLegacyResponse(BaseResponse):
    response: typing.List["GroupsGroupFull"] = None


class GetCallbackConfirmationCodeResponse(BaseResponse):
    response: "GetCallbackConfirmationCodeResponseModel" = None


class GetCallbackServersResponse(BaseResponse):
    response: "GetCallbackServersResponseModel" = None


class GetCallbackSettingsResponse(BaseResponse):
    response: GroupsCallbackSettings = None


class GetCatalogInfoExtendedResponse(BaseResponse):
    response: "GetCatalogInfoExtendedResponseModel" = None


class GetCatalogInfoResponse(BaseResponse):
    response: "GetCatalogInfoResponseModel" = None


class GetCatalogResponse(BaseResponse):
    response: "GetCatalogResponseModel" = None


class GetInvitedUsersResponse(BaseResponse):
    response: "GetInvitedUsersResponseModel" = None


class GetInvitesExtendedResponse(BaseResponse):
    response: "GetInvitesExtendedResponseModel" = None


class GetInvitesResponse(BaseResponse):
    response: "GetInvitesResponseModel" = None


class GetLongPollServerResponse(BaseResponse):
    response: GroupsLongPollServer = None


class GetLongPollSettingsResponse(BaseResponse):
    response: GroupsLongPollSettings = None


class GetMembersFieldsResponse(BaseResponse):
    response: "GetMembersFieldsResponseModel" = None


class GetMembersFilterResponse(BaseResponse):
    response: "GetMembersFilterResponseModel" = None


class GetMembersResponse(BaseResponse):
    response: "GetMembersResponseModel" = None


class GetRequestsFieldsResponse(BaseResponse):
    response: "GetRequestsFieldsResponseModel" = None


class GetRequestsResponse(BaseResponse):
    response: "GetRequestsResponseModel" = None


class GetSettingsResponse(BaseResponse):
    response: "GetSettingsResponseModel" = None


class GetTagListResponse(BaseResponse):
    response: typing.List["GroupsGroupTag"] = None


class GetTokenPermissionsResponse(BaseResponse):
    response: "GetTokenPermissionsResponseModel" = None


class GetObjectExtendedResponse(BaseResponse):
    response: "GetObjectExtendedResponseModel" = None


class GetResponse(BaseResponse):
    response: "GetResponseModel" = None


class IsMemberExtendedResponse(BaseResponse):
    response: "IsMemberExtendedResponseModel" = None


class IsMemberResponse(BaseResponse):
    response: BaseBoolInt = None


class IsMemberUserIdsExtendedResponse(BaseResponse):
    response: typing.List["GroupsMemberStatusFull"] = None


class IsMemberUserIdsResponse(BaseResponse):
    response: typing.List["GroupsMemberStatus"] = None


class SearchResponse(BaseResponse):
    response: "SearchResponseModel" = None


class AddCallbackServerResponseModel(BaseResponse):
    server_id: typing.Optional[int] = None


class GetAddressesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsAddress"]] = None


class GetBannedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsBannedItem"]] = None


class GetCallbackConfirmationCodeResponseModel(BaseResponse):
    code: typing.Optional[str] = None


class GetCallbackServersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsCallbackServer"]] = None


class GetCatalogInfoExtendedResponseModel(BaseResponse):
    enabled: typing.Optional["BaseBoolInt"] = None
    categories: typing.Optional[typing.List["GroupsGroupCategoryFull"]] = None


class GetCatalogInfoResponseModel(BaseResponse):
    enabled: typing.Optional["BaseBoolInt"] = None
    categories: typing.Optional[typing.List["GroupsGroupCategory"]] = None


class GetCatalogResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroup"]] = None


class GetInvitedUsersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetInvitesExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroupFull"]] = None
    profiles: typing.Optional[typing.List["UsersUserMin"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetInvitesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetMembersFieldsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsUserXtrRole"]] = None


class GetMembersFilterResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsMemberRole"]] = None


class GetMembersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class GetRequestsFieldsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetRequestsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class GetSettingsResponseModel(BaseResponse):
    access: typing.Optional["GroupsGroupAccess"] = None
    address: typing.Optional[str] = None
    audio: typing.Optional["GroupsGroupAudio"] = None
    articles: typing.Optional[int] = None
    recognize_photo: typing.Optional[int] = None
    city_id: typing.Optional[int] = None
    contacts: typing.Optional["BaseBoolInt"] = None
    links: typing.Optional["BaseBoolInt"] = None
    sections_list: typing.Optional[typing.List["GroupsSectionsListItem"]] = None
    main_section: typing.Optional["GroupsGroupFullSection"] = None
    secondary_section: typing.Optional["GroupsGroupFullSection"] = None
    age_limits: typing.Optional["GroupsGroupAgeLimits"] = None
    country_id: typing.Optional[int] = None
    description: typing.Optional[str] = None
    docs: typing.Optional["GroupsGroupDocs"] = None
    events: typing.Optional["BaseBoolInt"] = None
    obscene_filter: typing.Optional["BaseBoolInt"] = None
    obscene_stopwords: typing.Optional["BaseBoolInt"] = None
    obscene_words: typing.Optional[typing.List[str]] = None
    event_group_id: typing.Optional[int] = None
    photos: typing.Optional["GroupsGroupPhotos"] = None
    public_category: typing.Optional[int] = None
    public_category_list: typing.Optional[typing.List["GroupsGroupPublicCategoryList"]] = None
    public_date: typing.Optional[str] = None
    public_date_label: typing.Optional[str] = None
    public_subcategory: typing.Optional[int] = None
    rss: typing.Optional[str] = None
    start_date: typing.Optional[int] = None
    finish_date: typing.Optional[int] = None
    subject: typing.Optional[int] = None
    subject_list: typing.Optional[typing.List["GroupsSubjectItem"]] = None
    suggested_privacy: typing.Optional["GroupsGroupSuggestedPrivacy"] = None
    title: typing.Optional[str] = None
    topics: typing.Optional["GroupsGroupTopics"] = None
    twitter: typing.Optional["GroupsSettingsTwitter"] = None
    video: typing.Optional["GroupsGroupVideo"] = None
    wall: typing.Optional["GroupsGroupWall"] = None
    website: typing.Optional[str] = None
    phone: typing.Optional[str] = None
    email: typing.Optional[str] = None
    wiki: typing.Optional["GroupsGroupWiki"] = None


class GetTokenPermissionsResponseModel(BaseResponse):
    mask: typing.Optional[int] = None
    permissions: typing.Optional[typing.List["GroupsTokenPermissionSetting"]] = None


class GetObjectExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class IsMemberExtendedResponseModel(BaseResponse):
    member: typing.Optional["BaseBoolInt"] = None
    invitation: typing.Optional["BaseBoolInt"] = None
    can_invite: typing.Optional["BaseBoolInt"] = None
    can_recall: typing.Optional["BaseBoolInt"] = None
    request: typing.Optional["BaseBoolInt"] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroup"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()



import inspect
import typing
from .base_response import BaseResponse
import vkbottle_types.objects


class PaidStatusResponse(BaseResponse):
    response: "PaidStatusResponseModel" = None


class PaidStatusResponseModel(BaseResponse):
    is_paid: typing.Optional[bool] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()



import inspect
import typing
from .base_response import BaseResponse
from vkbottle_types.objects import (
    AccountAccountCounters,
    AccountInfo,
    AccountNameRequest,
    AccountOffer,
    AccountPushSettings,
    AccountUserSettings,
    BaseBoolInt,
    GroupsGroup,
    UsersUserFull
)


class ChangePasswordResponse(BaseResponse):
    response: "ChangePasswordResponseModel" = None


class GetActiveOffersResponse(BaseResponse):
    response: "GetActiveOffersResponseModel" = None


class GetAppPermissionsResponse(BaseResponse):
    response: int = None


class GetBannedResponse(BaseResponse):
    response: "GetBannedResponseModel" = None


class GetCountersResponse(BaseResponse):
    response: AccountAccountCounters = None


class GetInfoResponse(BaseResponse):
    response: AccountInfo = None


class GetProfileInfoResponse(BaseResponse):
    response: AccountUserSettings = None


class GetPushSettingsResponse(BaseResponse):
    response: AccountPushSettings = None


class SaveProfileInfoResponse(BaseResponse):
    response: "SaveProfileInfoResponseModel" = None


class ChangePasswordResponseModel(BaseResponse):
    token: typing.Optional[str] = None
    secret: typing.Optional[str] = None


class GetActiveOffersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AccountOffer"]] = None


class GetBannedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None


class SaveProfileInfoResponseModel(BaseResponse):
    changed: typing.Optional["BaseBoolInt"] = None
    name_request: typing.Optional["AccountNameRequest"] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()



import inspect
import typing
from .base_response import BaseResponse
from vkbottle_types.objects import (
    AppsApp,
    AppsCatalogList,
    AppsLeaderboard,
    AppsScope,
    UsersUserFull,
    UsersUserMin
)


class GetCatalogResponse(BaseResponse):
    response: AppsCatalogList = None


class GetFriendsListResponse(BaseResponse):
    response: "GetFriendsListResponseModel" = None


class GetLeaderboardExtendedResponse(BaseResponse):
    response: "GetLeaderboardExtendedResponseModel" = None


class GetLeaderboardResponse(BaseResponse):
    response: "GetLeaderboardResponseModel" = None


class GetMiniAppPoliciesResponse(BaseResponse):
    response: "GetMiniAppPoliciesResponseModel" = None


class GetScopesResponse(BaseResponse):
    response: "GetScopesResponseModel" = None


class GetScoreResponse(BaseResponse):
    response: int = None


class GetResponse(BaseResponse):
    response: "GetResponseModel" = None


class ImageUploadResponse(BaseResponse):
    response: "ImageUploadResponseModel" = None


class SendRequestResponse(BaseResponse):
    response: int = None


class GetFriendsListResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetLeaderboardExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsLeaderboard"]] = None
    profiles: typing.Optional[typing.List["UsersUserMin"]] = None


class GetLeaderboardResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsLeaderboard"]] = None


class GetMiniAppPoliciesResponseModel(BaseResponse):
    privacy_policy: typing.Optional[str] = None
    terms: typing.Optional[str] = None


class GetScopesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsScope"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AppsApp"]] = None


class ImageUploadResponseModel(BaseResponse):
    hash: typing.Optional[str] = None
    image: typing.Optional[str] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()



from typing import Union

from .bot_events import *  # noqa
from .bot_typings import GroupTypes
from .enums import GroupEventType, UserEventType
from .user_events import *  # noqa
from .user_typings import UserTypes

Event = Union[UserEventType, GroupEventType]



import inspect
import typing
from .base_response import BaseResponse
from vkbottle_types.objects import SearchHint


class GetHintsResponse(BaseResponse):
    response: "GetHintsResponseModel" = None


class GetHintsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["SearchHint"]] = None
    suggested_queries: typing.Optional[typing.List[str]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()
